==============
 zope.viewlet
==============

.. image:: https://img.shields.io/pypi/v/zope.viewlet.svg
        :target: https://pypi.python.org/pypi/zope.viewlet/
        :alt: Latest release

.. image:: https://img.shields.io/pypi/pyversions/zope.viewlet.svg
        :target: https://pypi.org/project/zope.viewlet/
        :alt: Supported Python versions

.. image:: https://travis-ci.org/zopefoundation/zope.viewlet.svg?branch=master
        :target: https://travis-ci.org/zopefoundation/zope.viewlet

.. image:: https://coveralls.io/repos/github/zopefoundation/zope.viewlet/badge.svg?branch=master
        :target: https://coveralls.io/github/zopefoundation/zope.viewlet?branch=master

.. image:: https://readthedocs.org/projects/zopeviewlet/badge/?version=latest
        :target: https://zopeviewlet.readthedocs.io/en/latest/
        :alt: Documentation Status


Viewlets provide a generic framework for building pluggable user
interfaces. Viewlets are a special type of `content provider
<https://pypi.python.org/pypi/zope.contentprovider>`_ that allows a
template to define a region (a "viewlet manager"") into which content
("viewlets") can be plugged.

Documentation is hosted at https://zopeviewlet.readthedocs.io/
